@@ -9,6 +9,7 @@ from typing import Any
 from typing import Callable
 from typing import Dict
 from typing import List
+from typing import Literal
 from typing import Optional
 from typing import Set
 from typing import Tuple
@@ -16,22 +17,16 @@ from typing import TypeVar
 
 from typing_extensions import ParamSpec
 
+import pwndbg.aglib.heap
+import pwndbg.aglib.kernel
+import pwndbg.aglib.proc
+import pwndbg.aglib.qemu
+import pwndbg.aglib.regs
 import pwndbg.exception
-
-# These aren't available under LLDB, and we can't get rid of them until all of
-# this functionality has been ported to the Debugger API.
-#
-# TODO: Replace these with uses of the Debugger API.
-if pwndbg.dbg.is_gdblib_available():
-    import pwndbg.gdblib.heap
-    import pwndbg.gdblib.kernel
-    import pwndbg.gdblib.proc
-    import pwndbg.gdblib.qemu
-    import pwndbg.gdblib.regs
-    from pwndbg.gdblib.heap.ptmalloc import DebugSymsHeap
-    from pwndbg.gdblib.heap.ptmalloc import GlibcMemoryAllocator
-    from pwndbg.gdblib.heap.ptmalloc import HeuristicHeap
-    from pwndbg.gdblib.heap.ptmalloc import SymbolUnresolvableError
+from pwndbg.aglib.heap.ptmalloc import DebugSymsHeap
+from pwndbg.aglib.heap.ptmalloc import GlibcMemoryAllocator
+from pwndbg.aglib.heap.ptmalloc import HeuristicHeap
+from pwndbg.aglib.heap.ptmalloc import SymbolUnresolvableError
 
 log = logging.getLogger(__name__)
 
@@ -46,7 +41,8 @@ class CommandCategory(str, Enum):
     START = "Start"
     NEXT = "Step/Next/Continue"
     CONTEXT = "Context"
-    HEAP = "Heap"
+    PTMALLOC2 = "GLibc ptmalloc2 Heap"
+    JEMALLOC = "jemalloc Heap"
     BREAKPOINT = "Breakpoint"
     MEMORY = "Memory"
     STACK = "Stack"
@@ -78,7 +74,15 @@ if pwndbg.dbg.is_gdblib_available():
 class Command:
     """Generic command wrapper"""
 
-    builtin_override_whitelist: Set[str] = {"up", "down", "search", "pwd", "start", "ignore"}
+    builtin_override_whitelist: Set[str] = {
+        "up",
+        "down",
+        "search",
+        "pwd",
+        "start",
+        "starti",
+        "ignore",
+    }
     history: Dict[int, str] = {}
 
     def __init__(
@@ -127,6 +131,9 @@ class Command:
     def split_args(self, argument: str) -> Tuple[List[str], Dict[Any, Any]]:
         """Split a command-line string from the user into arguments.
 
+        This is only used by pwndbg/commands/shell.py which is deprecated.
+        Usually _ArgparsedCommand.split_args is called.
+
         Returns:
             A ``(tuple, dict)``, in the form of ``*args, **kwargs``.
             The contents of the tuple/dict are undefined.
@@ -135,19 +142,20 @@ class Command:
 
     def invoke(self, argument: str, from_tty: bool) -> None:
         """Invoke the command with an argument string"""
+        if not pwndbg.dbg.selected_inferior():
+            log.error("Pwndbg commands require a target binary to be selected")
+            return
+
         try:
             args, kwargs = self.split_args(argument)
         except SystemExit:
             # Raised when the usage is printed by an ArgparsedCommand
+            # because of an error in argument parsing
             return
         except (TypeError, pwndbg.dbg_mod.Error):
             pwndbg.exception.handle(self.function.__name__)
             return
 
-        if not pwndbg.dbg.selected_inferior():
-            log.error("Pwndbg commands require a target binary to be selected")
-            return
-
         try:
             self.repeat = self.check_repeated(argument, from_tty)
             self(*args, **kwargs)
@@ -199,10 +207,10 @@ def fix(
     """Fix a single command-line argument coming from the CLI.
 
     Arguments:
-        arg(str): Original string representation (e.g. '0', '$rax', '$rax+44')
-        sloppy(bool): If ``arg`` cannot be evaluated, return ``arg``. (default: False)
-        quiet(bool): If an error occurs, suppress it. (default: True)
-        reraise(bool): If an error occurs, raise the exception. (default: False)
+        arg: Original string representation (e.g. '0', '$rax', '$rax+44')
+        sloppy: If ``arg`` cannot be evaluated, return ``arg``. (default: False)
+        quiet: If an error occurs, suppress it. (default: True)
+        reraise: If an error occurs, raise the exception. (default: False)
 
     Returns:
         Ideally a ``Value`` object.  May return a ``str`` if ``sloppy==True``.
@@ -233,7 +241,7 @@ def fix(
         # no debugger-agnostic architecture functions. Those will come later.
         #
         # TODO: Port architecutre functions and `pwndbg.gdblib.regs.fix` to debugger-agnostic API and remove this.
-        arg = pwndbg.gdblib.regs.fix(arg)
+        arg = pwndbg.aglib.regs.fix(arg)
         return target.evaluate_expression(arg)
     except Exception as e:
         ex = e
@@ -268,6 +276,18 @@ def fix_reraise(*a, **kw) -> str | pwndbg.dbg_mod.Value | None:
     return fix(*a, reraise=True, **kw)  # type: ignore[misc]
 
 
+def fix_reraise_arg(arg) -> pwndbg.dbg_mod.Value:
+    """fix_reraise wrapper for evaluating command arguments"""
+    try:
+        # Will always return pwndbg.dbg_mod.Value because
+        # sloppy=False (not str) and reraise=True (not None)
+        fixed = fix(arg, sloppy=False, quiet=True, reraise=True)
+        assert isinstance(fixed, pwndbg.dbg_mod.Value)
+        return fixed
+    except pwndbg.dbg_mod.Error as dbge:
+        raise argparse.ArgumentTypeError(f"debugger couldn't resolve argument '{arg}': {dbge}")
+
+
 def fix_int(*a, **kw) -> int:
     return int(fix(*a, **kw))
 
@@ -276,16 +296,48 @@ def fix_int_reraise(*a, **kw) -> int:
     return fix_int(*a, reraise=True, **kw)
 
 
+def fix_int_reraise_arg(arg) -> int:
+    """fix_int_reraise wrapper for evaluating command arguments"""
+    try:
+        fixed = fix_reraise_arg(arg)
+        return int(fixed)
+    except pwndbg.dbg_mod.Error as e:
+        raise argparse.ArgumentTypeError(
+            f"couldn't convert '{arg}' ({fixed.type.name_to_human_readable}) to int: {e}"
+        )
+
+
+def func_name(function: Callable[P, T]) -> str:
+    return function.__name__.replace("_", "-")
+
+
+def OnlyWhenLocal(function: Callable[P, T]) -> Callable[P, Optional[T]]:
+    @functools.wraps(function)
+    def _OnlyWhenLocal(*a: P.args, **kw: P.kwargs) -> Optional[T]:
+        if not pwndbg.aglib.remote.is_remote():
+            return function(*a, **kw)
+
+        msg = f'The "remote" target does not support "{function.__name__}".'
+
+        if pwndbg.dbg.is_gdblib_available():
+            msg += ' Try "help target" or "continue".'
+
+        log.error(msg)
+        return None
+
+    return _OnlyWhenLocal
+
+
 def OnlyWithFile(function: Callable[P, T]) -> Callable[P, Optional[T]]:
     @functools.wraps(function)
     def _OnlyWithFile(*a: P.args, **kw: P.kwargs) -> Optional[T]:
-        if pwndbg.gdblib.proc.exe:
+        if pwndbg.aglib.proc.exe:
             return function(*a, **kw)
         else:
-            if pwndbg.gdblib.qemu.is_qemu():
+            if pwndbg.aglib.qemu.is_qemu():
                 log.error("Could not determine the target binary on QEMU.")
             else:
-                log.error(f"{function.__name__}: There is no file loaded.")
+                log.error(f"{func_name(function)}: There is no file loaded.")
             return None
 
     return _OnlyWithFile
@@ -294,11 +346,11 @@ def OnlyWithFile(function: Callable[P, T]) -> Callable[P, Optional[T]]:
 def OnlyWhenQemuKernel(function: Callable[P, T]) -> Callable[P, Optional[T]]:
     @functools.wraps(function)
     def _OnlyWhenQemuKernel(*a: P.args, **kw: P.kwargs) -> Optional[T]:
-        if pwndbg.gdblib.qemu.is_qemu_kernel():
+        if pwndbg.aglib.qemu.is_qemu_kernel():
             return function(*a, **kw)
         else:
             log.error(
-                f"{function.__name__}: This command may only be run when debugging the Linux kernel in QEMU."
+                f"{func_name(function)}: This command may only be run when debugging the Linux kernel in QEMU."
             )
             return None
 
@@ -308,50 +360,25 @@ def OnlyWhenQemuKernel(function: Callable[P, T]) -> Callable[P, Optional[T]]:
 def OnlyWhenUserspace(function: Callable[P, T]) -> Callable[P, Optional[T]]:
     @functools.wraps(function)
     def _OnlyWhenUserspace(*a: P.args, **kw: P.kwargs) -> Optional[T]:
-        if not pwndbg.gdblib.qemu.is_qemu_kernel():
+        if not pwndbg.aglib.qemu.is_qemu_kernel():
             return function(*a, **kw)
         else:
             log.error(
-                f"{function.__name__}: This command may only be run when not debugging a QEMU kernel target."
+                f"{func_name(function)}: This command may only be run when not debugging a QEMU kernel target."
             )
             return None
 
     return _OnlyWhenUserspace
 
 
-def OnlyWithArch(arch_names: List[str]) -> Callable[[Callable[P, T]], Callable[P, Optional[T]]]:
-    """Decorates function to work only with the specified archictectures."""
-    for arch in arch_names:
-        if arch not in pwndbg.gdblib.arch_mod.ARCHS:
-            raise ValueError(
-                f"OnlyWithArch used with unsupported arch={arch}. Must be one of {', '.join(arch_names)}"
-            )
-
-    def decorator(function: Callable[P, T]) -> Callable[P, Optional[T]]:
-        @functools.wraps(function)
-        def _OnlyWithArch(*a: P.args, **kw: P.kwargs) -> Optional[T]:
-            if pwndbg.gdblib.arch.name in arch_names:
-                return function(*a, **kw)
-            else:
-                arches_str = ", ".join(arch_names)
-                log.error(
-                    f"{function.__name__}: This command may only be run on the {arches_str} architecture(s)"
-                )
-                return None
-
-        return _OnlyWithArch
-
-    return decorator
-
-
 def OnlyWithKernelDebugSyms(function: Callable[P, T]) -> Callable[P, Optional[T]]:
     @functools.wraps(function)
     def _OnlyWithKernelDebugSyms(*a: P.args, **kw: P.kwargs) -> Optional[T]:
-        if pwndbg.gdblib.kernel.has_debug_syms():
+        if pwndbg.aglib.kernel.has_debug_syms():
             return function(*a, **kw)
         else:
             log.error(
-                f"{function.__name__}: This command may only be run when debugging a Linux kernel with debug symbols."
+                f"{func_name(function)}: This command may only be run when debugging a Linux kernel with debug symbols."
             )
             return None
 
@@ -361,10 +388,12 @@ def OnlyWithKernelDebugSyms(function: Callable[P, T]) -> Callable[P, Optional[T]
 def OnlyWhenPagingEnabled(function: Callable[P, T]) -> Callable[P, Optional[T]]:
     @functools.wraps(function)
     def _OnlyWhenPagingEnabled(*a: P.args, **kw: P.kwargs) -> Optional[T]:
-        if pwndbg.gdblib.kernel.paging_enabled():
+        if pwndbg.aglib.kernel.paging_enabled():
             return function(*a, **kw)
         else:
-            log.error(f"{function.__name__}: This command may only be run when paging is enabled.")
+            log.error(
+                f"{func_name(function)}: This command may only be run when paging is enabled."
+            )
             return None
 
     return _OnlyWhenPagingEnabled
@@ -373,10 +402,11 @@ def OnlyWhenPagingEnabled(function: Callable[P, T]) -> Callable[P, Optional[T]]:
 def OnlyWhenRunning(function: Callable[P, T]) -> Callable[P, Optional[T]]:
     @functools.wraps(function)
     def _OnlyWhenRunning(*a: P.args, **kw: P.kwargs) -> Optional[T]:
-        if pwndbg.gdblib.proc.alive:
+        # TODO: Properly support OnlyWhenRunning without `gdblib`.
+        if pwndbg.aglib.proc.alive:
             return function(*a, **kw)
         else:
-            log.error(f"{function.__name__}: The program is not being run.")
+            log.error(f"{func_name(function)}: The program is not being run.")
             return None
 
     return _OnlyWhenRunning
@@ -385,12 +415,12 @@ def OnlyWhenRunning(function: Callable[P, T]) -> Callable[P, Optional[T]]:
 def OnlyWithTcache(function: Callable[P, T]) -> Callable[P, Optional[T]]:
     @functools.wraps(function)
     def _OnlyWithTcache(*a: P.args, **kw: P.kwargs) -> Optional[T]:
-        assert isinstance(pwndbg.gdblib.heap.current, GlibcMemoryAllocator)
-        if pwndbg.gdblib.heap.current.has_tcache():
+        assert isinstance(pwndbg.aglib.heap.current, GlibcMemoryAllocator)
+        if pwndbg.aglib.heap.current.has_tcache():
             return function(*a, **kw)
         else:
             log.error(
-                f"{function.__name__}: This version of GLIBC was not compiled with tcache support."
+                f"{func_name(function)}: This version of GLIBC was not compiled with tcache support."
             )
             return None
 
@@ -400,21 +430,15 @@ def OnlyWithTcache(function: Callable[P, T]) -> Callable[P, Optional[T]]:
 def OnlyWhenHeapIsInitialized(function: Callable[P, T]) -> Callable[P, Optional[T]]:
     @functools.wraps(function)
     def _OnlyWhenHeapIsInitialized(*a: P.args, **kw: P.kwargs) -> Optional[T]:
-        if pwndbg.gdblib.heap.current is not None and pwndbg.gdblib.heap.current.is_initialized():
+        if pwndbg.aglib.heap.current is not None and pwndbg.aglib.heap.current.is_initialized():
             return function(*a, **kw)
         else:
-            log.error(f"{function.__name__}: Heap is not initialized yet.")
+            log.error(f"{func_name(function)}: Heap is not initialized yet.")
             return None
 
     return _OnlyWhenHeapIsInitialized
 
 
-# TODO/FIXME: Move this elsewhere? Have better logic for that? Maybe caching?
-def _is_statically_linked() -> bool:
-    out = gdb.execute("info dll", to_string=True)
-    return "No shared libraries loaded at this time." in out
-
-
 def _try2run_heap_command(function: Callable[P, T], *a: P.args, **kw: P.kwargs) -> T | None:
     e = log.error
     w = log.warning
@@ -422,7 +446,7 @@ def _try2run_heap_command(function: Callable[P, T], *a: P.args, **kw: P.kwargs)
     try:
         return function(*a, **kw)
     except SymbolUnresolvableError as err:
-        e(f"{function.__name__}: Fail to resolve the symbol: `{err.symbol}`")
+        e(f"{func_name(function)}: Fail to resolve the symbol: `{err.symbol}`")
         if "thread_arena" == err.symbol:
             w(
                 "You are probably debugging a multi-threaded target without debug symbols, so we failed to determine which arena is used by the current thread.\n"
@@ -437,8 +461,8 @@ def _try2run_heap_command(function: Callable[P, T], *a: P.args, **kw: P.kwargs)
 
         pwndbg.exception.inform_verbose_and_debug()
     except Exception as err:
-        e(f"{function.__name__}: An unknown error occurred when running this command.")
-        if isinstance(pwndbg.gdblib.heap.current, HeuristicHeap):
+        e(f"{func_name(function)}: An unknown error occurred when running this command.")
+        if isinstance(pwndbg.aglib.heap.current, HeuristicHeap):
             w(
                 "Maybe you can try to determine the libc symbols addresses manually, set them appropriately and re-run this command. For this, see the `heap_config` command output and set the `main_arena`, `mp_`, `global_max_fast`, `tcache` and `thread_arena` addresses."
             )
@@ -455,35 +479,36 @@ def OnlyWithResolvedHeapSyms(function: Callable[P, T]) -> Callable[P, T | None]:
     @functools.wraps(function)
     def _OnlyWithResolvedHeapSyms(*a: P.args, **kw: P.kwargs) -> T | None:
         e = log.error
-        w = log.warn
+        w = log.warning
         if (
-            isinstance(pwndbg.gdblib.heap.current, HeuristicHeap)
+            isinstance(pwndbg.aglib.heap.current, HeuristicHeap)
             and pwndbg.config.resolve_heap_via_heuristic == "auto"
             and DebugSymsHeap().can_be_resolved()
         ):
             # In auto mode, we will try to use the debug symbols if possible
-            pwndbg.gdblib.heap.current = DebugSymsHeap()
+            pwndbg.aglib.heap.current = DebugSymsHeap()
         if (
-            pwndbg.gdblib.heap.current is not None
-            and isinstance(pwndbg.gdblib.heap.current, GlibcMemoryAllocator)
-            and pwndbg.gdblib.heap.current.can_be_resolved()
+            pwndbg.aglib.heap.current is not None
+            and isinstance(pwndbg.aglib.heap.current, GlibcMemoryAllocator)
+            and pwndbg.aglib.heap.current.can_be_resolved()
         ):
             return _try2run_heap_command(function, *a, **kw)
         else:
+            static = not pwndbg.dbg.selected_inferior().is_dynamically_linked()
             if (
-                isinstance(pwndbg.gdblib.heap.current, DebugSymsHeap)
+                isinstance(pwndbg.aglib.heap.current, DebugSymsHeap)
                 and pwndbg.config.resolve_heap_via_heuristic == "auto"
             ):
                 # In auto mode, if the debug symbols are not enough, we will try to use the heuristic if possible
                 heuristic_heap = HeuristicHeap()
                 if heuristic_heap.can_be_resolved():
-                    pwndbg.gdblib.heap.current = heuristic_heap
+                    pwndbg.aglib.heap.current = heuristic_heap
                     w(
                         "pwndbg will try to resolve the heap symbols via heuristic now since we cannot resolve the heap via the debug symbols.\n"
                         "This might not work in all cases. Use `help set resolve-heap-via-heuristic` for more details.\n"
                     )
                     return _try2run_heap_command(function, *a, **kw)
-                elif _is_statically_linked():
+                elif static:
                     e(
                         "Can't find GLIBC version required for this command to work since this is a statically linked binary"
                     )
@@ -499,7 +524,7 @@ def OnlyWithResolvedHeapSyms(function: Callable[P, T]) -> Callable[P, T | None]:
                         "Please set the GLIBC version you think the target binary was compiled (using `set glibc <version>` command; e.g. 2.32) and re-run this command"
                     )
             elif (
-                isinstance(pwndbg.gdblib.heap.current, DebugSymsHeap)
+                isinstance(pwndbg.aglib.heap.current, DebugSymsHeap)
                 and pwndbg.config.resolve_heap_via_heuristic == "force"
             ):
                 e(
@@ -507,7 +532,7 @@ def OnlyWithResolvedHeapSyms(function: Callable[P, T]) -> Callable[P, T | None]:
                 )
                 w("Use `set resolve-heap-via-heuristic auto` and re-run this command.")
             elif pwndbg.glibc.get_version() is None:
-                if _is_statically_linked():
+                if static:
                     e("Can't resolve the heap since the GLIBC version is not set.")
                     w(
                         "Please set the GLIBC version you think the target binary was compiled (using `set glibc <version>` command; e.g. 2.32) and re-run this command."
@@ -542,7 +567,9 @@ class _ArgparsedCommand(Command):
     ) -> None:
         self.parser = parser
         if command_name is None:
-            self.parser.prog = function.__name__
+            # Take the command name from the name of the function
+            # which defines it, but replace '_' with '-'.
+            self.parser.prog = function.__name__.replace("_", "-")
         else:
             self.parser.prog = command_name
 
@@ -556,7 +583,7 @@ class _ArgparsedCommand(Command):
         # Type error likely due to https://github.com/python/mypy/issues/6799
         super().__init__(  # type: ignore[misc]
             function,
-            command_name=command_name,
+            command_name=self.parser.prog,
             doc=doc,
             *a,
             **kw,
@@ -573,9 +600,11 @@ class ArgparsedCommand:
     def __init__(
         self,
         parser_or_desc: argparse.ArgumentParser | str,
-        aliases: List[str] = [],
+        category: CommandCategory,
         command_name: str | None = None,
-        category: CommandCategory = CommandCategory.MISC,
+        aliases: List[str] = [],
+        only_debuggers: Set[pwndbg.dbg_mod.DebuggerType] = None,
+        exclude_debuggers: Set[pwndbg.dbg_mod.DebuggerType] = None,
     ) -> None:
         """
         :param parser_or_desc: `argparse.ArgumentParser` instance or `str`
@@ -583,10 +612,15 @@ class ArgparsedCommand:
         if isinstance(parser_or_desc, str):
             self.parser = argparse.ArgumentParser(description=parser_or_desc)
         else:
+            assert isinstance(parser_or_desc, argparse.ArgumentParser)
             self.parser = parser_or_desc
         self.aliases = aliases
+        assert command_name is None or "_" not in command_name
         self._command_name = command_name
+        assert category
         self.category = category
+        self.only_debuggers = only_debuggers
+        self.exclude_debuggers = exclude_debuggers
         # We want to run all integer and otherwise-unspecified arguments
         # through fix() so that GDB parses it.
         for action in self.parser._actions:
@@ -594,14 +628,19 @@ class ArgparsedCommand:
                 action.type = str
             if action.dest == "help":
                 continue
-            if action.type == int:
-                action.type = fix_int_reraise
+            if action.type is int:
+                action.type = fix_int_reraise_arg
             if action.type is None:
-                action.type = fix_reraise
+                action.type = fix_reraise_arg
             if action.default is not None:
                 action.help += " (default: %(default)s)"
 
     def __call__(self, function: Callable[..., Any]) -> _ArgparsedCommand:
+        if self.only_debuggers is not None and pwndbg.dbg.name() not in self.only_debuggers:
+            return function  # type: ignore[return-value]
+        if self.exclude_debuggers is not None and pwndbg.dbg.name() in self.exclude_debuggers:
+            return function  # type: ignore[return-value]
+
         for alias in self.aliases:
             _ArgparsedCommand(
                 self.parser, function, command_name=alias, is_alias=True, category=self.category
@@ -615,22 +654,6 @@ class ArgparsedCommand:
         )
 
 
-# These values are only used by `sloppy_gdb_parse`, and it, in turn, only seems
-# to end up being used by `pwndbg.commands.windbg`, through `AddressExpr` and
-# `HexOrAddressExpr`. By gating both these values and the `windbg` command family
-# behind `is_gdblib_available`, we get around that.
-#
-# TODO: Remove this after the `windbg` command family has been ported to the Debugger API.
-if pwndbg.dbg.is_gdblib_available():
-    import gdb
-
-    # We use a 64-bit max value literal here instead of pwndbg.gdblib.arch.current
-    # as realistically its ok to pull off the biggest possible type here
-    # We cache its GDB value type which is 'unsigned long long'
-    _mask = 0xFFFFFFFFFFFFFFFF
-    _mask_val_type = gdb.Value(_mask).type
-
-
 def sloppy_gdb_parse(s: str) -> int | str:
     """
     This function should be used as ``argparse.ArgumentParser`` .add_argument method's `type` helper.
@@ -650,13 +673,9 @@ def sloppy_gdb_parse(s: str) -> int | str:
 
     try:
         val = target.evaluate_expression(s)
-        # We can't just return int(val) because GDB may return:
-        # "Python Exception <class 'gdb.error'> Cannot convert value to long."
-        # e.g. for:
-        # pwndbg> pi int(gdb.parse_and_eval('__libc_start_main'))
-        #
-        # Here, the _mask_val.type should be `unsigned long long`
-        return int(val.cast(_mask_val_type))
+        if val.type.code == pwndbg.dbg_mod.TypeCode.FUNC:
+            return int(val.address)
+        return int(val)
     except (TypeError, pwndbg.dbg_mod.Error):
         return s
 
@@ -690,81 +709,92 @@ def load_commands() -> None:
 
     if pwndbg.dbg.is_gdblib_available():
         import pwndbg.commands.ai
-        import pwndbg.commands.argv
-        import pwndbg.commands.aslr
-        import pwndbg.commands.asm
         import pwndbg.commands.attachp
-        import pwndbg.commands.auxv
-        import pwndbg.commands.binder
-        import pwndbg.commands.binja
+        import pwndbg.commands.binja_functions
         import pwndbg.commands.branch
-        import pwndbg.commands.canary
-        import pwndbg.commands.checksec
-        import pwndbg.commands.comments
-        import pwndbg.commands.config
-        import pwndbg.commands.context
-        import pwndbg.commands.cpsr
-        import pwndbg.commands.cyclic
         import pwndbg.commands.cymbol
-        import pwndbg.commands.dev
-        import pwndbg.commands.distance
-        import pwndbg.commands.dt
-        import pwndbg.commands.dumpargs
-        import pwndbg.commands.elf
-        import pwndbg.commands.flags
-        import pwndbg.commands.ghidra
-        import pwndbg.commands.godbg
         import pwndbg.commands.got
         import pwndbg.commands.got_tracking
-        import pwndbg.commands.heap
-        import pwndbg.commands.heap_tracking
-        import pwndbg.commands.hexdump
+        import pwndbg.commands.ptmalloc2_tracking
         import pwndbg.commands.ida
         import pwndbg.commands.ignore
-        import pwndbg.commands.integration
         import pwndbg.commands.ipython_interactive
-        import pwndbg.commands.kbase
-        import pwndbg.commands.kchecksec
-        import pwndbg.commands.kcmdline
-        import pwndbg.commands.kconfig
         import pwndbg.commands.killthreads
-        import pwndbg.commands.kversion
-        import pwndbg.commands.leakfind
-        import pwndbg.commands.linkmap
-        import pwndbg.commands.memoize
-        import pwndbg.commands.misc
-        import pwndbg.commands.mmap
-        import pwndbg.commands.mprotect
-        import pwndbg.commands.nearpc
-        import pwndbg.commands.next
-        import pwndbg.commands.onegadget
-        import pwndbg.commands.p2p
-        import pwndbg.commands.patch
-        import pwndbg.commands.pcplist
         import pwndbg.commands.peda
-        import pwndbg.commands.pie
-        import pwndbg.commands.plist
-        import pwndbg.commands.probeleak
-        import pwndbg.commands.procinfo
-        import pwndbg.commands.radare2
         import pwndbg.commands.reload
-        import pwndbg.commands.retaddr
-        import pwndbg.commands.rizin
-        import pwndbg.commands.rop
         import pwndbg.commands.ropper
-        import pwndbg.commands.search
         import pwndbg.commands.segments
         import pwndbg.commands.shell
-        import pwndbg.commands.sigreturn
-        import pwndbg.commands.slab
-        import pwndbg.commands.spray
-        import pwndbg.commands.start
-        import pwndbg.commands.telescope
-        import pwndbg.commands.tips
-        import pwndbg.commands.tls
-        import pwndbg.commands.valist
-        import pwndbg.commands.version
-        import pwndbg.commands.vmmap
-        import pwndbg.commands.windbg
-        import pwndbg.commands.xinfo
-        import pwndbg.commands.xor
+
+    import pwndbg.commands.argv
+    import pwndbg.commands.aslr
+    import pwndbg.commands.asm
+    import pwndbg.commands.auxv
+    import pwndbg.commands.binder
+    import pwndbg.commands.binja
+    import pwndbg.commands.canary
+    import pwndbg.commands.checksec
+    import pwndbg.commands.comments
+    import pwndbg.commands.config
+    import pwndbg.commands.context
+    import pwndbg.commands.cpsr
+    import pwndbg.commands.cyclic
+    import pwndbg.commands.dev
+    import pwndbg.commands.distance
+    import pwndbg.commands.dt
+    import pwndbg.commands.dumpargs
+    import pwndbg.commands.elf
+    import pwndbg.commands.flags
+    import pwndbg.commands.gdt
+    import pwndbg.commands.ghidra
+    import pwndbg.commands.godbg
+    import pwndbg.commands.hex2ptr
+    import pwndbg.commands.hexdump
+    import pwndbg.commands.hijack_fd
+    import pwndbg.commands.integration
+    import pwndbg.commands.jemalloc
+    import pwndbg.commands.kbase
+    import pwndbg.commands.kchecksec
+    import pwndbg.commands.kcmdline
+    import pwndbg.commands.kconfig
+    import pwndbg.commands.klookup
+    import pwndbg.commands.knft
+    import pwndbg.commands.kversion
+    import pwndbg.commands.leakfind
+    import pwndbg.commands.libcinfo
+    import pwndbg.commands.linkmap
+    import pwndbg.commands.memoize
+    import pwndbg.commands.misc
+    import pwndbg.commands.mmap
+    import pwndbg.commands.mprotect
+    import pwndbg.commands.nearpc
+    import pwndbg.commands.next
+    import pwndbg.commands.onegadget
+    import pwndbg.commands.p2p
+    import pwndbg.commands.patch
+    import pwndbg.commands.pcplist
+    import pwndbg.commands.pie
+    import pwndbg.commands.plist
+    import pwndbg.commands.probeleak
+    import pwndbg.commands.procinfo
+    import pwndbg.commands.profiler
+    import pwndbg.commands.ptmalloc2
+    import pwndbg.commands.radare2
+    import pwndbg.commands.retaddr
+    import pwndbg.commands.rizin
+    import pwndbg.commands.rop
+    import pwndbg.commands.search
+    import pwndbg.commands.sigreturn
+    import pwndbg.commands.slab
+    import pwndbg.commands.spray
+    import pwndbg.commands.start
+    import pwndbg.commands.strings
+    import pwndbg.commands.telescope
+    import pwndbg.commands.tips
+    import pwndbg.commands.tls
+    import pwndbg.commands.valist
+    import pwndbg.commands.version
+    import pwndbg.commands.vmmap
+    import pwndbg.commands.windbg
+    import pwndbg.commands.xinfo
+    import pwndbg.commands.xor
