@@ -2,8 +2,9 @@ from __future__ import annotations
 
 import gdb
 
+import pwndbg.aglib.proc
+import pwndbg.aglib.regs
 import pwndbg.commands
-import pwndbg.gdblib.regs
 from pwndbg.commands import CommandCategory
 
 
@@ -15,7 +16,7 @@ class segment(gdb.Function):
         self.name = name
 
     def invoke(self, arg: gdb.Value = gdb.Value(0), *args: gdb.Value) -> int:
-        result = getattr(pwndbg.gdblib.regs, self.name)
+        result = getattr(pwndbg.aglib.regs, self.name)
         return result + int(arg)
 
 
@@ -28,21 +29,21 @@ segment("gsbase")
     "Prints out the FS base address. See also $fsbase.", category=CommandCategory.REGISTER
 )
 @pwndbg.commands.OnlyWhenRunning
-@pwndbg.commands.OnlyWithArch(["i386", "x86-64"])
+@pwndbg.aglib.proc.OnlyWithArch(["i386", "x86-64"])
 def fsbase() -> None:
     """
     Prints out the FS base address. See also $fsbase.
     """
-    print(hex(int(pwndbg.gdblib.regs.fsbase)))
+    print(hex(int(pwndbg.aglib.regs.fsbase)))
 
 
 @pwndbg.commands.ArgparsedCommand(
     "Prints out the GS base address. See also $gsbase.", category=CommandCategory.REGISTER
 )
 @pwndbg.commands.OnlyWhenRunning
-@pwndbg.commands.OnlyWithArch(["i386", "x86-64"])
+@pwndbg.aglib.proc.OnlyWithArch(["i386", "x86-64"])
 def gsbase() -> None:
     """
     Prints out the GS base address. See also $gsbase.
     """
-    print(hex(int(pwndbg.gdblib.regs.gsbase)))
+    print(hex(int(pwndbg.aglib.regs.gsbase)))
