@@ -5,24 +5,26 @@ Command to print the virtual memory map a la /proc/self/maps.
 from __future__ import annotations
 
 import argparse
+import os.path
 from typing import Tuple
 
-import gdb
 from elftools.elf.constants import SH_FLAGS
 from elftools.elf.elffile import ELFFile
 
+import pwndbg.aglib.arch
+import pwndbg.aglib.elf
+import pwndbg.aglib.file
+import pwndbg.aglib.vmmap
+import pwndbg.aglib.vmmap_custom
 import pwndbg.color.memory as M
 import pwndbg.commands
-import pwndbg.gdblib.elf
-import pwndbg.gdblib.vmmap
 from pwndbg.color import cyan
 from pwndbg.color import green
 from pwndbg.color import red
 from pwndbg.commands import CommandCategory
-from pwndbg.gdblib import gdb_version
 from pwndbg.lib.memory import Page
 
-integer_types = (int, gdb.Value)
+integer_types = (int, pwndbg.dbg_mod.Value)
 
 
 def pages_filter(gdbval_or_str):
@@ -44,8 +46,11 @@ def print_vmmap_table_header() -> None:
     """
     Prints the table header for the vmmap command.
     """
+    prefer_relpaths = "on" if pwndbg.config.vmmap_prefer_relpaths else "off"
+    width = 2 + 2 * pwndbg.aglib.arch.ptrsize
     print(
-        f"{'Start':>{2 + 2 * pwndbg.gdblib.arch.ptrsize}} {'End':>{2 + 2 * pwndbg.gdblib.arch.ptrsize}} {'Perm'} {'Size':>8} {'Offset':>6} {'File'}"
+        f"{'Start':>{width}} {'End':>{width}} {'Perm'} {'Size':>8} {'Offset':>6} "
+        f"{'File'} (set vmmap-prefer-relpaths {prefer_relpaths})"
     )
 
 
@@ -54,12 +59,12 @@ def print_vmmap_gaps_table_header() -> None:
     Prints the table header for the vmmap --gaps command.
     """
     header = (
-        f"{'Start':>{2 + 2 * pwndbg.gdblib.arch.ptrsize}} "
-        f"{'End':>{2 + 2 * pwndbg.gdblib.arch.ptrsize}} "
+        f"{'Start':>{2 + 2 * pwndbg.aglib.arch.ptrsize}} "
+        f"{'End':>{2 + 2 * pwndbg.aglib.arch.ptrsize}} "
         f"{'Perm':>4} "
         f"{'Size':>8} "
         f"{'Note':>9} "
-        f"{'Accumulated Size':>{2 + 2 * pwndbg.gdblib.arch.ptrsize}}"
+        f"{'Accumulated Size':>{2 + 2 * pwndbg.aglib.arch.ptrsize}}"
     )
     print(header)
 
@@ -87,7 +92,7 @@ def print_map(page: Page) -> None:
 def print_adjacent_map(map_start: Page, map_end: Page) -> None:
     print(
         green(
-            f"{gap_text(map_end)} {'ADJACENT':>9} {hex(map_end.end - map_start.start):>{2 + 2 * pwndbg.gdblib.arch.ptrsize}}"
+            f"{gap_text(map_end)} {'ADJACENT':>9} {hex(map_end.end - map_start.start):>{2 + 2 * pwndbg.aglib.arch.ptrsize}}"
         )
     )
 
@@ -100,7 +105,7 @@ def print_gap(current: Page, last_map: Page):
     print(
         red(
             " - " * int(51 / 3)
-            + f" {'GAP':>9} {hex(current.start - last_map.end):>{2 + 2 * pwndbg.gdblib.arch.ptrsize}}"
+            + f" {'GAP':>9} {hex(current.start - last_map.end):>{2 + 2 * pwndbg.aglib.arch.ptrsize}}"
         )
     )
 
@@ -179,6 +184,9 @@ parser.add_argument(
 parser.add_argument(
     "-B", "--lines-before", type=int, help="Number of pages to display before result", default=1
 )
+parser.add_argument(
+    "-C", "--context", type=int, help="Number of pages to display around the result"
+)
 parser.add_argument(
     "--gaps",
     action="store_true",
@@ -191,16 +199,26 @@ parser.add_argument(
 )
 @pwndbg.commands.OnlyWhenRunning
 def vmmap(
-    gdbval_or_str=None, writable=False, executable=False, lines_after=1, lines_before=1, gaps=False
+    gdbval_or_str=None,
+    writable=False,
+    executable=False,
+    lines_after=1,
+    lines_before=1,
+    context=None,
+    gaps=False,
 ) -> None:
     lookaround_lines_limit = 64
 
     # Implement a sane limit
-    lines_after = min(lookaround_lines_limit, lines_after)
-    lines_before = min(lookaround_lines_limit, lines_before)
+    if context is not None:
+        lines_after = lines_before = min(lookaround_lines_limit, context)
+    else:
+        lines_after = min(lookaround_lines_limit, lines_after)
+        lines_before = min(lookaround_lines_limit, lines_before)
 
     # All displayed pages, including lines after and lines before
-    total_pages = pwndbg.gdblib.vmmap.get()
+    vmmap = pwndbg.dbg.selected_inferior().vmmap()
+    total_pages = vmmap.ranges()
 
     # Filtered memory pages, indicated by a backtrace arrow in results
     filtered_pages = []
@@ -240,7 +258,7 @@ def vmmap(
         return
 
     if gaps:
-        print_vmmap_gaps(total_pages)
+        print_vmmap_gaps(tuple(total_pages))
         return
 
     print(M.legend())
@@ -263,25 +281,25 @@ def vmmap(
 
         print(M.get(page.vaddr, text=display_text, prefix=backtrace_prefix))
 
-    if pwndbg.gdblib.qemu.is_qemu() and not pwndbg.gdblib.qemu.exec_file_supported():
-        print("\n[QEMU target detected - vmmap result might not be accurate; see `help vmmap`]")
-
-    # Only GDB versions >=12 report permission info in info proc mappings. On older versions, we fallback on "rwx".
-    # See https://github.com/bminor/binutils-gdb/commit/29ef4c0699e1b46d41ade00ae07a54f979ea21cc
-    if pwndbg.gdblib.qemu.is_qemu_usermode() and gdb_version[0] < 12:
+    if vmmap.is_qemu():
         print(
-            "\n[GDB <12.1 detected - vmmap cannot fetch permission information, defaulting to rwx]"
+            "\n[QEMU <8.1 target detected - vmmap result might not be accurate; see `help vmmap`]"
         )
 
 
 parser = argparse.ArgumentParser(description="Add virtual memory map page.")
-parser.add_argument("start", help="Starting virtual address")
-parser.add_argument("size", help="Size of the address space, in bytes")
+parser.add_argument("start", type=int, help="Starting virtual address")
+parser.add_argument("size", type=int, help="Size of the address space, in bytes")
 parser.add_argument(
-    "flags", nargs="?", type=str, default="", help="Flags set by the ELF file, see PF_X, PF_R, PF_W"
+    "flags",
+    nargs="?",
+    type=str,
+    default="",
+    help="Flags set by the ELF file (r - read, w - write, x - executable)",
 )
 parser.add_argument(
     "offset",
+    type=int,
     nargs="?",
     default=0,
     help="Offset into the original ELF file that the data is loaded from",
@@ -290,11 +308,11 @@ parser.add_argument(
 
 @pwndbg.commands.ArgparsedCommand(parser, category=CommandCategory.MEMORY)
 @pwndbg.commands.OnlyWhenRunning
-def vmmap_add(start, size, flags, offset) -> None:
+def vmmap_add(start: int, size: int, flags: str, offset: int) -> None:
     page_flags = {
-        "r": pwndbg.gdblib.elf.PF_R,
-        "w": pwndbg.gdblib.elf.PF_W,
-        "x": pwndbg.gdblib.elf.PF_X,
+        "r": pwndbg.aglib.elf.PF_R,
+        "w": pwndbg.aglib.elf.PF_W,
+        "x": pwndbg.aglib.elf.PF_X,
     }
     perm = 0
     for flag in flags:
@@ -305,32 +323,65 @@ def vmmap_add(start, size, flags, offset) -> None:
         perm |= flag_val
 
     page = pwndbg.lib.memory.Page(start, size, perm, offset)
-    pwndbg.gdblib.vmmap.add_custom_page(page)
+    pwndbg.aglib.vmmap_custom.add_custom_page(page)
 
     print("%r added" % page)
 
 
+parser = argparse.ArgumentParser(description="Explore a page, trying to guess permissions.")
+parser.add_argument(
+    "address", type=pwndbg.commands.sloppy_gdb_parse, help="Address of the page to explore"
+)
+
+
+@pwndbg.commands.ArgparsedCommand(parser, category=CommandCategory.MEMORY)
+@pwndbg.commands.OnlyWhenRunning
+def vmmap_explore(address: int) -> None:
+    if not isinstance(address, int):
+        print("Address is not a valid integer.")
+        return
+
+    old_value = pwndbg.config.auto_explore_pages.value
+    pwndbg.config.auto_explore_pages.value = "yes"
+    try:
+        pwndbg.aglib.vmmap.find.cache.clear()  # type: ignore[attr-defined]
+        page = pwndbg.aglib.vmmap.find(address)
+    finally:
+        pwndbg.config.auto_explore_pages.value = old_value
+
+    if page is None:
+        print("Exploration failed. Maybe the address isn't readable?")
+        return
+
+    print_vmmap_table_header()
+    print(page)
+
+
 @pwndbg.commands.ArgparsedCommand(
     "Clear the vmmap cache.", category=CommandCategory.MEMORY
 )  # TODO is this accurate?
 @pwndbg.commands.OnlyWhenRunning
 def vmmap_clear() -> None:
-    pwndbg.gdblib.vmmap.clear_custom_page()
+    pwndbg.aglib.vmmap_custom.clear_custom_page()
 
 
 parser = argparse.ArgumentParser(description="Load virtual memory map pages from ELF file.")
 parser.add_argument(
-    "filename", nargs="?", type=str, help="ELF filename, by default uses current loaded filename."
+    "filename",
+    nargs="?",
+    type=str,
+    help="ELF filename, by default uses current loaded filename.",
 )
 
 
-@pwndbg.commands.ArgparsedCommand(parser, category=CommandCategory.MEMORY)
+@pwndbg.commands.ArgparsedCommand(parser, category=CommandCategory.MISC)
 @pwndbg.commands.OnlyWhenRunning
 def vmmap_load(filename) -> None:
     if filename is None:
-        filename = pwndbg.gdblib.file.get_proc_exe_file()
+        filename = pwndbg.aglib.file.get_proc_exe_file()
 
     print(f'Load "{filename}" ...')
+    file_basename = os.path.basename(filename)
 
     # TODO: Add an argument to let use to choose loading the page information from sections or segments
 
@@ -354,35 +405,17 @@ def vmmap_load(filename) -> None:
                 continue
 
             # Guess the segment flags from section flags
-            flags = pwndbg.gdblib.elf.PF_R
+            flags = pwndbg.aglib.elf.PF_R
             if sh_flags & SH_FLAGS.SHF_WRITE:
-                flags |= pwndbg.gdblib.elf.PF_W
+                flags |= pwndbg.aglib.elf.PF_W
             if sh_flags & SH_FLAGS.SHF_EXECINSTR:
-                flags |= pwndbg.gdblib.elf.PF_X
+                flags |= pwndbg.aglib.elf.PF_X
 
-            page = pwndbg.lib.memory.Page(vaddr, memsz, flags, offset, filename)
+            page = pwndbg.lib.memory.Page(
+                vaddr, memsz, flags, offset, f"[{section.name}]: {file_basename}"
+            )
             pages.append(page)
 
     for page in pages:
-        pwndbg.gdblib.vmmap.add_custom_page(page)
+        pwndbg.aglib.vmmap_custom.add_custom_page(page)
         print("%r added" % page)
-
-
-parser = argparse.ArgumentParser(description="Explore a page, trying to guess permissions.")
-parser.add_argument(
-    "address", type=pwndbg.commands.sloppy_gdb_parse, help="Address of the page to explore"
-)
-
-
-@pwndbg.commands.ArgparsedCommand(parser, category=CommandCategory.MEMORY)
-@pwndbg.commands.OnlyWhenRunning
-def vmmap_explore(address: int) -> None:
-    if not isinstance(address, int):
-        print("Address is not a valid integer.")
-        return
-    page = pwndbg.gdblib.vmmap.explore(address)
-    if page is None:
-        print("Exploration failed. Maybe the address isn't readable?")
-        return
-    print_vmmap_table_header()
-    print(page)
